@@ -15,19 +15,21 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#define ARROW_VERSION_MAJOR 6
+#define ARROW_VERSION_MAJOR 7
 #define ARROW_VERSION_MINOR 0
-#define ARROW_VERSION_PATCH 1
+#define ARROW_VERSION_PATCH 0
 #define ARROW_VERSION ((ARROW_VERSION_MAJOR * 1000) + ARROW_VERSION_MINOR) * 1000 + ARROW_VERSION_PATCH
 
-#define ARROW_VERSION_STRING "6.0.1"
+#define ARROW_VERSION_STRING "7.0.0"
 
-#define ARROW_SO_VERSION "600"
-#define ARROW_FULL_SO_VERSION "600.1.0"
+#define ARROW_SO_VERSION "700"
+#define ARROW_FULL_SO_VERSION "700.0.0"
 
-#define ARROW_CXX_COMPILER_ID "GNU"
-#define ARROW_CXX_COMPILER_VERSION "10.2.0"
-#define ARROW_CXX_COMPILER_FLAGS "-D_FORTIFY_SOURCE=2 -march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt -fdiagnostics-color=always -O3 -DNDEBUG"
+#define ARROW_CXX_COMPILER_ID "Clang"
+#define ARROW_CXX_COMPILER_VERSION "13.0.1"
+#define ARROW_CXX_COMPILER_FLAGS "-march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -Wp,-D_GLIBCXX_ASSERTIONS -Qunused-arguments -fcolor-diagnostics -O3 -DNDEBUG"
+
+#define ARROW_BUILD_TYPE "RELEASE"
 
 #define ARROW_GIT_ID ""
 #define ARROW_GIT_DESCRIPTION ""
@@ -44,5 +46,6 @@
 
 /* #undef ARROW_S3 */
 #define ARROW_USE_NATIVE_INT128
+/* #undef ARROW_WITH_OPENTELEMETRY */
 
 #define GRPCPP_PP_INCLUDE
